@@ -18,7 +18,7 @@ from collections import defaultdict
 import attr
 
 from hypothesis.internal.compat import int_from_bytes, int_to_bytes
-from hypothesis.internal.conjecture.choicetree import ChoiceTree
+from hypothesis.internal.conjecture.choicetree import ChoiceTree, prefix_selection_order
 from hypothesis.internal.conjecture.data import ConjectureResult, Overrun, Status
 from hypothesis.internal.conjecture.floats import (
     DRAW_FLOAT_LABEL,
@@ -483,7 +483,6 @@ class Shrinker:
         This method iterates to a fixed point and so is idempontent - calling
         it twice will have exactly the same effect as calling it once.
         """
-
         self.fixate_shrink_passes(
             [
                 block_program("X" * 5),
@@ -571,9 +570,6 @@ class Shrinker:
             if 0 < len(successful_passes) < len(passes):
                 self.fixate_shrink_passes(successful_passes)
 
-        for sp in passes:
-            sp.fixed_point_at = self.shrink_target
-
     @property
     def buffer(self):
         return self.shrink_target.buffer
@@ -1452,17 +1448,13 @@ class ShrinkPass:
     index = attr.ib()
     shrinker = attr.ib()
 
-    next_prefix = attr.ib(default=())
-    fixed_point_at = attr.ib(default=None)
+    last_prefix = attr.ib(default=())
     successes = attr.ib(default=0)
     calls = attr.ib(default=0)
     shrinks = attr.ib(default=0)
     deletions = attr.ib(default=0)
 
     def step(self):
-        if self.fixed_point_at is self.shrinker.shrink_target:
-            return False
-
         tree = self.shrinker.shrink_pass_choice_trees[self]
         if tree.exhausted:
             return False
@@ -1472,8 +1464,8 @@ class ShrinkPass:
         size = len(self.shrinker.shrink_target.buffer)
         self.shrinker.explain_next_call_as(self.name)
         try:
-            self.next_prefix = tree.step(
-                self.next_prefix,
+            self.last_prefix = tree.step(
+                prefix_selection_order(self.last_prefix),
                 lambda chooser: self.run_with_chooser(self.shrinker, chooser),
             )
         finally:
